@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -18,9 +18,10 @@ along with this program if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from qt import QString, QObject, QByteArray, QEvent, QSplitter, QHeaderView
+from qt import QObject, QByteArray, QEvent, QSplitter, QHeaderView
 
-from common import Internal, isAlive, english
+from common import Internal, isAlive
+from mi18n import english
 
 
 class StateSaver(QObject):
@@ -51,7 +52,7 @@ class StateSaver(QObject):
     @staticmethod
     def __restore(widget, name):
         """decode the saved string"""
-        state = QByteArray.fromHex(Internal.Preferences[name])
+        state = QByteArray.fromHex(Internal.Preferences[name].encode())
         if state:
             if name.endswith('State'):
                 widget.restoreState(state)
@@ -105,13 +106,16 @@ class StateSaver(QObject):
             saver.save()
         Internal.Preferences.writeConfig()
 
+    @staticmethod
+    def stateStr(state):
+        """convert hex string to str"""
+        return str(bytes(state.toHex()).decode())
+
     def save(self):
         """writes the state into Preferences, but does not save"""
         for name, widget in self.widgets:
             if isAlive(widget):
                 if hasattr(widget, 'saveState'):
-                    Internal.Preferences[name + 'State'] = QString(
-                        widget.saveState().toHex())
+                    Internal.Preferences[name + 'State'] = self.stateStr(widget.saveState())
                 if hasattr(widget, 'saveGeometry'):
-                    Internal.Preferences[name + 'Geometry'] = QString(
-                        widget.saveGeometry().toHex())
+                    Internal.Preferences[name + 'Geometry'] = self.stateStr(widget.saveGeometry())
